from django.db import models
from django.contrib.auth import get_user_model

from tickets.models import Ticket


class Tasks(models.Model):
    """
    Задачи
    """
    repr_id = models.ForeignKey(get_user_model(), related_name="repr_id", blank=True, on_delete=models.DO_NOTHING, help_text="Уникальный идентификатор ответственного за задачу")
    user_id = models.ForeignKey(get_user_model(), on_delete=models.DO_NOTHING, null=True, help_text="уникальный идентификатор пользователя/клиента/аккаунта, который должен выполнить задачу")
    task_description = models.TextField(blank=True, help_text="текстовое описание услуги")
    status = models.CharField(max_length=150, help_text="активность на основе системы заявок", default="deactivated")
    dead_line = models.DateTimeField(auto_now_add=True, help_text="дедлайн выполнения задачи")
    ticket_status = models.ForeignKey(Ticket, on_delete=models.DO_NOTHING, null=True, help_text="id последнего актуального тикета, касающийся статуса. Если он меняет статус на закрытый - вызывается проверка, которая смотрит, нет ли другого открытого по пользователю.")
    id_metaservice = models.BigIntegerField(help_text=" уникальный идентификатор мета-сервиса, необходимый для синхронизации данных. Один и тот же провайдер может быть для нескольких мета-сервисов, соответственно если происходят изменения в одном, то либо форсируется изменение во всех (если возможно), либо снимается is_global. Соответственно при изменении is_global в true должно происходить согласование с остальными копиями в других сервисах. Нужен в том числе для того, чтобы выяснять, в каких еще сервисах есть этот провайдер.")
    is_global = models.BooleanField(default=False, help_text="доступно ли для планирования в цепочке с другими услугами в глобальном сервисе")
    is_visible = models.BooleanField(default=False, help_text="доступно ли для хранения в глобальном сервисе/нужна синхронизация данных")

    class Meta:
        db_table = "tasks"
        verbose_name = "Задачи"
        verbose_name_plural = "Задачи"